import Prism from 'prismjs';
import rehypeParse from 'rehype-parse';
import { unified } from 'unified';
import { h } from 'hastscript';
import { select } from 'unist-util-select';
import { getLang } from './get-lang.js';
import { Checker } from './checker.js';
import { appendClassName } from './append-class-name.js';
import { getLineNumber } from './get-line-number.js';
const parser = unified()
    .use(rehypeParse, { fragment: true });
export function parseCodeVisitor(options) {
    return node => {
        var _a;
        if (!Checker.isElement(node) || node.tagName !== 'pre')
            return;
        const preNode = node;
        const codeNode = select('[tagName=code]', preNode);
        if (!Checker.isElement(codeNode))
            return;
        const lang = getLang(codeNode);
        if (!lang || !Prism.languages[lang])
            return;
        const textNode = select('text', codeNode);
        if (!Checker.isText(textNode))
            return;
        const codeText = textNode.value;
        const html = Prism.highlight(codeText, Prism.languages[lang], lang);
        const tree = parser.parse(html);
        appendClassName(preNode, `language-${lang}`);
        codeNode.children = [...tree.children];
        if ((_a = options === null || options === void 0 ? void 0 : options.plugins) === null || _a === void 0 ? void 0 : _a.includes('line-numbers')) {
            appendClassName(preNode, 'line-numbers');
            const lineNumber = getLineNumber(codeText);
            const lineNumberColumn = h('span', {
                'aria-hidden': 'true',
                className: ['line-numbers-rows'],
            }, new Array(lineNumber).fill(h('span')));
            codeNode.children.push(lineNumberColumn);
        }
    };
}
